<?php
/**
 * Plugin Support
 *
 * Support for Jetpack & WooCommerce
 *
 * @package      responsive_mobile
 * @license      license.txt
 * @copyright    2014 CyberChimps Inc
 * @since        0.0.1
 *
 * Please do not edit this file. This file is part of the responsive_mobile Framework and all modifications
 * should be made in a child theme.
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Add theme support for Infinite Scroll.
 * See: http://jetpack.me/support/infinite-scroll/
 */
function responsive_mobile_infinite_scroll_render() {
	get_template_part( 'template-parts/content', get_post_format() );
}

function responsive_mobile_jetpack_setup() {
	add_theme_support( 'infinite-scroll', array(
		'footer_widgets' => array( 'colophon-widget', 'footer-widget', ),
		'container'      => 'main',
		'render'         => 'responsive_mobile_infinite_scroll_render', 
		'footer'         => 'page',
	) );
}
add_action( 'after_setup_theme', 'responsive_mobile_jetpack_setup' );

function responsive_mobile_jetpack_credit() {
	$powered_by_text = sprintf(
		/* Translators: Responsive Theme powered by WordPress */
		__( '%1$s powered by %2$s', 'responsive-mobile' ),
		'<a href="' . esc_url( 'http://cyberchimps.com/responsive-theme/' ) . '">' . __( 'Responsive Theme', 'responsive-mobile' ) . '</a>',
		'<a href="' . esc_url( 'http://wordpress.org/' ) . '">' . __( 'WordPress', 'responsive-mobile' ) . '</a>'
	);
	$powered_by_text = apply_filters( 'responsive_mobile_powered_by_text', $powered_by_text );
	return $powered_by_text;
}
add_filter( 'infinite_scroll_credit', 'responsive_mobile_jetpack_credit' );

/**
 * WooCommerce
 *
 * Unhook/Hook the WooCommerce Wrappers
 */
function responsive_mobile_woocommerce_wrapper() {
	echo '<div id="content-woocommerce" class="content-area"><main id="main" class="site-main" role="main">';
}
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
add_action( 'woocommerce_before_main_content', 'responsive_mobile_woocommerce_wrapper', 10 );

function responsive_mobile_woocommerce_wrapper_end() {
	echo '</main><!-- #main -->';
}
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
add_action( 'woocommerce_after_main_content', 'responsive_mobile_woocommerce_wrapper_end', 10 );

function responsive_mobile_woocommerce_content_end() {
	echo '</div><!-- #content-woocommerce -->';
}
add_action( 'woocommerce_sidebar', 'responsive_mobile_woocommerce_content_end', 11 );
