<?php
/**
 * Content None Template
 *
 * The template part for displaying a message that posts cannot be found.
 *
 * @package      responsive_mobile
 * @license      license.txt
 * @copyright    2014 CyberChimps Inc
 * @since        0.0.1
 *
 * Please do not edit this file. This file is part of the responsive_mobile Framework and all modifications
 * should be made in a child theme.
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
?>

<?php responsive_mobile_entry_before(); ?>
<section id="post-0" class="error404 no-results not-found">
	<?php responsive_mobile_entry_top(); ?>

	<div class="page-content">
		<?php if ( is_home() || is_archive() && current_user_can( 'publish_posts' ) ) : ?>

			<header class="page-header">
				<h1 class="title-title"><?php _e( 'No posts published yet', 'responsive-mobile' ) ?></h1>
			</header><!-- .page-header -->

			<p>
				<?php _e( 'Ready to publish your first post?', 'responsive-mobile' ); ?>
				<?php echo '<a href="' . esc_url( admin_url( 'post-new.php' ) . '">' . __( 'Get started here', 'responsive-mobile' ) ) . '</a>' ?>
			</p>

		<?php elseif ( is_search() ) : ?>

			<header class="page-header">
				<h1 class="title-title"><?php _e( 'No results', 'responsive-mobile' ) ?></h1>
			</header><!-- .page-header -->

			<p><?php printf( __( 'Your search for "%s" did not match any entries.', 'responsive-mobile' ), get_search_query() ); ?></p>
			<?php get_search_form(); ?>

		<?php else : ?>

			<header class="page-header">
				<h1 class="title-404"><?php _e( '404 &#8212; Fancy meeting you here!', 'responsive-mobile' ) ?></h1>
			</header><!-- .page-header -->

			<p><?php _e( 'Don&#39;t panic, we&#39;ll get through this together. Let&#39;s explore our options here.', 'responsive-mobile' ); ?></p>
			<p><?php _e( 'The URL may be misspelled or the page you are looking for is no longer available.', 'responsive-mobile' ); ?></p>

			<p>
				<?php printf(
						__( 'You can return %s or search for the page you were looking for.', 'responsive-mobile' ),
						sprintf(
							'<a href="%1$s" title="%2$s">%3$s</a>',
							esc_url( get_home_url() ),
							esc_attr__( 'Home', 'responsive-mobile' ),
							esc_attr__( '&larr; Home', 'responsive-mobile' )
						)
				); ?>
			</p>

			<?php get_search_form(); ?>

		<?php endif; ?>
	</div><!-- .page-content -->
</section><!-- .no-results -->
